# ERP Utils

## Use
To know how to install it, see the documentation in [packages](https://gitlab.com/TheFurnitureGuys/erp/erp-utils/-/packages)
select the version you like install and enter for view details, for example:
[v 0.1.27](https://gitlab.com/TheFurnitureGuys/erp/erp-utils/-/packages/3423594)

## Use in requirements.txt file
Add in requirements.txt 

    -i http://gitlab.com/api/v4/projects/29184144/packages/pypi/simple
    erp-utils

and execute 

    pip install -r requirements.txt